import { __decorate, __metadata, __param } from 'tslib';
import { InjectionToken, NgModule, ElementRef, Optional, Inject, Input, Directive } from '@angular/core';
import { DOCUMENT } from '@angular/common';
import { FormsModule, NgModel } from '@angular/forms';
import hljs from 'highlight.js/lib/highlight.js';
import typescript from 'highlight.js/lib/languages/typescript';
import html from 'highlight.js/lib/languages/xml';

var HLJS = new InjectionToken('hljs lib', {
    providedIn: 'root',
    factory: function () { return hljs; },
});
function configurationFactory(config) {
    console.log('config', config);
    hljs.registerLanguage('typescript', typescript);
    hljs.registerLanguage('xml', html);
    return hljs;
}
var HighlightJsModule = /** @class */ (function () {
    function HighlightJsModule() {
    }
    HighlightJsModule_1 = HighlightJsModule;
    HighlightJsModule.forRoot = function (config) {
        return {
            ngModule: HighlightJsModule_1,
            providers: [
                { provide: HLJS, useFactory: configurationFactory, deps: [config] }
            ],
        };
    };
    var HighlightJsModule_1;
    HighlightJsModule = HighlightJsModule_1 = __decorate([
        NgModule({
            imports: [FormsModule],
            declarations: [HighlightJsDirective],
            exports: [HighlightJsDirective]
        })
    ], HighlightJsModule);
    return HighlightJsModule;
}());

// declare const hljs: any;
var HighlightJsDirective = /** @class */ (function () {
    function HighlightJsDirective(el, ngModel, doc, hljs) {
        this.el = el;
        this.ngModel = ngModel;
        this.doc = doc;
        this.hljs = hljs;
        this.lang = 'html';
    }
    HighlightJsDirective.prototype.escapeHTML = function (str) {
        return (str || '')
            .replace(/&/g, '&amp;')
            .replace(/</g, '&lt;')
            .replace(/>/g, '&gt;')
            .replace(/"/g, '&quot;')
            .replace(/'/g, '&apos;');
    };
    HighlightJsDirective.prototype.init = function () {
        this.destroy();
        this.codeEl = this.doc.createElement('pre');
        if (this.lang) {
            this.codeEl.className = this.lang;
        }
        this.codeEl.innerHTML =
            this.code || '' + this.el.nativeElement.innerHTML.trim();
        this.parentEl = this.el.nativeElement.parentNode;
        this.parentEl.insertBefore(this.codeEl, this.el.nativeElement.nextSibling);
        this.hljs.configure(Object.assign({}, this.options));
        this.hljs.highlightBlock(this.codeEl);
    };
    HighlightJsDirective.prototype.destroy = function () {
        if (this.codeEl) {
            this.parentEl.removeChild(this.codeEl);
            this.codeEl = null;
        }
    };
    HighlightJsDirective.prototype.ngOnInit = function () {
        this.init();
    };
    HighlightJsDirective.prototype.ngAfterViewInit = function () {
        var _this = this;
        if (this.ngModel) {
            this.modelValue$ = this.ngModel.valueChanges.subscribe(function (res) {
                _this.code = _this.escapeHTML(res);
                _this.init();
            });
        }
        else {
            this.initMutation();
        }
    };
    HighlightJsDirective.prototype.ngOnDestroy = function () {
        this.destroy();
        this.destroyMutation();
        if (this.modelValue$) {
            this.modelValue$.unsubscribe();
        }
    };
    HighlightJsDirective.prototype.initMutation = function () {
        if (typeof MutationObserver === 'undefined')
            return;
        this.observer = new MutationObserver(this.init.bind(this));
        this.observer.observe(this.el.nativeElement, {
            characterData: true,
            childList: true,
            subtree: true,
        });
    };
    HighlightJsDirective.prototype.destroyMutation = function () {
        if (!this.observer)
            return;
        this.observer.disconnect();
    };
    HighlightJsDirective.ctorParameters = function () { return [
        { type: ElementRef },
        { type: NgModel, decorators: [{ type: Optional }] },
        { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] }] },
        { type: undefined, decorators: [{ type: Inject, args: [HLJS,] }] }
    ]; };
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], HighlightJsDirective.prototype, "options", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], HighlightJsDirective.prototype, "lang", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], HighlightJsDirective.prototype, "code", void 0);
    HighlightJsDirective = __decorate([
        Directive({
            selector: '[highlight-js]',
            host: {
                style: 'display:none;',
            },
            exportAs: 'highlightJs',
        }),
        __param(1, Optional()),
        __param(2, Inject(DOCUMENT)),
        __param(3, Inject(HLJS)),
        __metadata("design:paramtypes", [ElementRef,
            NgModel, Object, Object])
    ], HighlightJsDirective);
    return HighlightJsDirective;
}());

/**
 * Generated bundle index. Do not edit.
 */

export { HLJS, HighlightJsDirective, HighlightJsModule };
//# sourceMappingURL=ngx-highlight-js-fork.js.map
